Skip to contents

Transforms any projected or geographic CRS to EPSG:4326. Returns the input unchanged if it is not an sfc object. If the CRS is already EPSG:4326, no transformation is performed. If an sf geometry has missing CRS, the geom_sf() IR path warns "geom_sf layer has missing CRS; coordinates will be serialized as-is" and leaves coordinates unchanged.

Usage

normalize_to_wgs84(geom_col)

Arguments

geom_col

An sfc geometry column, or any other R object

Value

The sfc column transformed to EPSG:4326, or the input unchanged if not an sfc object